@@ -1,19 +1,28 @@
 import json
+from typing import Dict
 
-from mindee.inputs import (
-    InputDocument,
-    Base64Document,
-    BytesDocument,
-    FileDocument,
-    PathDocument,
-)
-from mindee.response import format_response, DocumentResponse
-from mindee.http import HTTPException
 from mindee.document_config import DocumentConfig, DocumentConfigDict
-from mindee.documents.receipt import Receipt
+from mindee.documents.custom_document import CustomDocument
 from mindee.documents.financial_document import FinancialDocument
 from mindee.documents.invoice import Invoice
 from mindee.documents.passport import Passport
+from mindee.documents.receipt import Receipt
+from mindee.http import (
+    CustomEndpoint,
+    HTTPException,
+    InvoiceEndpoint,
+    PassportEndpoint,
+    ReceiptEndpoint,
+)
+from mindee.inputs import (
+    Base64Document,
+    BytesDocument,
+    FileDocument,
+    InputDocument,
+    PathDocument,
+)
+from mindee.logger import logger
+from mindee.response import DocumentResponse, format_response
 
 
 class DocumentClient:
@@ -35,10 +44,14 @@ class DocumentClient:
         self, document_type: str, username: str = None, include_words: bool = False
     ):
         """
+        Call prediction API on the document and parse the results.
+
         :param document_type: Document type to parse
         :param username:
         :param include_words: Bool, extract all words into http_response
         """
+        logger.debug("Parsing document as '%s'", document_type)
+
         found = []
         for k in self.doc_configs.keys():
             if k[1] == document_type:
@@ -56,8 +69,8 @@ class DocumentClient:
                     (
                         "Duplicate configuration detected.\n"
                         f"You specified a document_type '{document_type}' in your custom config.\n"
-                        "To avoid confusion, please add the 'account_name' attribute to the parse method, "
-                        f"one of {usernames}."
+                        "To avoid confusion, please add the 'account_name' attribute to "
+                        f"the parse method, one of {usernames}."
                     )
                 )
         else:
@@ -68,8 +81,10 @@ class DocumentClient:
             if not endpoint.api_key:
                 raise RuntimeError(
                     (
-                        f"Missing API key for '{endpoint.key_name}', check your Client configuration.\n"
-                        f"You can set this using the '{endpoint.envvar_key_name}' environment variable."
+                        f"Missing API key for '{endpoint.key_name}',"
+                        "check your Client configuration.\n"
+                        "You can set this using the "
+                        f"'{endpoint.envvar_key_name}' environment variable."
                     )
                 )
         return self._make_request(doc_config, include_words)
@@ -105,14 +120,11 @@ class Client:
 
     def __init__(self, raise_on_error: bool = True):
         """
+        Mindee API Client.
+
         :param raise_on_error: Raise an Exception on HTTP errors
         """
-        self._doc_configs = {
-            ("mindee", "receipt"): Receipt.get_document_config(),
-            ("mindee", "invoice"): Invoice.get_document_config(),
-            ("mindee", "financial_doc"): FinancialDocument.get_document_config(),
-            ("mindee", "passport"): Passport.get_document_config(),
-        }
+        self._doc_configs: Dict[tuple, DocumentConfig] = {}
         self.raise_on_error = raise_on_error
 
     def config_custom_doc(
@@ -130,22 +142,28 @@ class Client:
         See: https://developers.mindee.com/docs/
 
         :param document_type: The "document type" field in the "Settings" page of the API Builder
-        :param singular_name: The name of the attribute used to retrieve a *single* document from the API response
-        :param plural_name: The name of the attribute used to retrieve *multiple* documents from the API response
+        :param singular_name: The name of the attribute used to retrieve
+            a *single* document from the API response
+        :param plural_name: The name of the attribute used to retrieve
+            *multiple* documents from the API response
         :param account_name: Your organization's username on the API Builder
         :param api_key: Your API key for the endpoint
         :param version: If set, locks the version of the model to use.
                         If not set, use the latest version of the model.
         """
         self._doc_configs[(account_name, document_type)] = DocumentConfig(
-            {
-                "document_type": document_type,
-                "singular_name": singular_name,
-                "plural_name": plural_name,
-                "account_name": account_name,
-                "api_key": api_key,
-                "interface_version": version,
-            }
+            document_type=document_type,
+            singular_name=singular_name,
+            plural_name=plural_name,
+            constructor=CustomDocument,
+            endpoints=[
+                CustomEndpoint(
+                    owner=account_name,
+                    url_name=document_type,
+                    version=version,
+                    api_key=api_key,
+                ),
+            ],
         )
         return self
 
@@ -157,8 +175,14 @@ class Client:
 
         :param api_key: Invoice API key
         """
-        if api_key:
-            self._doc_configs[("mindee", "invoice")].endpoints[0].api_key = api_key
+        config = DocumentConfig(
+            document_type="invoice",
+            singular_name="invoice",
+            plural_name="invoices",
+            constructor=Invoice,
+            endpoints=[InvoiceEndpoint(api_key=api_key)],
+        )
+        self._doc_configs[("mindee", "invoice")] = config
         return self
 
     def config_receipt(self, api_key: str = None):
@@ -169,8 +193,14 @@ class Client:
 
         :param api_key: Expense Receipt API key
         """
-        if api_key:
-            self._doc_configs[("mindee", "receipt")].endpoints[0].api_key = api_key
+        config = DocumentConfig(
+            document_type="receipt",
+            singular_name="receipt",
+            plural_name="receipts",
+            constructor=Receipt,
+            endpoints=[ReceiptEndpoint(api_key=api_key)],
+        )
+        self._doc_configs[("mindee", "receipt")] = config
         return self
 
     def config_financial_doc(
@@ -184,14 +214,17 @@ class Client:
         :param receipt_api_key: Expense Receipt API key
         :param invoice_api_key: Invoice API key
         """
-        if invoice_api_key:
-            self._doc_configs[("mindee", "financial_doc")].endpoints[
-                0
-            ].api_key = invoice_api_key
-        if receipt_api_key:
-            self._doc_configs[("mindee", "financial_doc")].endpoints[
-                1
-            ].api_key = receipt_api_key
+        config = DocumentConfig(
+            document_type="financial_doc",
+            singular_name="financial_doc",
+            plural_name="financial_docs",
+            constructor=FinancialDocument,
+            endpoints=[
+                InvoiceEndpoint(api_key=invoice_api_key),
+                ReceiptEndpoint(api_key=receipt_api_key),
+            ],
+        )
+        self._doc_configs[("mindee", "financial_doc")] = config
         return self
 
     def config_passport(self, api_key: str = None):
@@ -202,8 +235,14 @@ class Client:
 
         :param api_key: Passport API key
         """
-        if api_key:
-            self._doc_configs[("mindee", "passport")].endpoints[0].api_key = api_key
+        config = DocumentConfig(
+            document_type="passport",
+            singular_name="passport",
+            plural_name="passports",
+            constructor=Passport,
+            endpoints=[PassportEndpoint(api_key=api_key)],
+        )
+        self._doc_configs[("mindee", "passport")] = config
         return self
 
     def doc_from_path(
