@@ -1,68 +1,33 @@
-from typing import List
+from typing import List, Optional
 
-from mindee.fields.amount import Amount
-from mindee.fields.date import Date
-from mindee.fields.locale import Locale
-from mindee.fields.orientation import Orientation
-from mindee.fields.tax import Tax
-from mindee.fields import Field
-from mindee.http import make_api_request, API_TYPE_OFF_THE_SHELF, Endpoint
 from mindee.documents.base import Document
 from mindee.documents.invoice import Invoice
 from mindee.documents.receipt import Receipt
-from mindee.document_config import DocumentConfig
+from mindee.fields import Field
+from mindee.fields.locale import Locale
+from mindee.fields.orientation import Orientation
+from mindee.http import Endpoint
 
 
 class FinancialDocument(Document):
+    locale: Locale
+    # orientation is only present on page-level, not document-level
+    orientation: Optional[Orientation] = None
+
     def __init__(
         self,
         api_prediction=None,
         input_file=None,
-        locale=None,
-        total_incl=None,
-        total_excl=None,
-        date=None,
-        invoice_number=None,
-        due_date=None,
-        taxes=None,
-        merchant_name=None,
-        payment_details=None,
-        company_number=None,
-        vat_number=None,
-        orientation=None,
-        total_tax=None,
-        time=None,
         page_n=0,
         document_type="financial_doc",
     ):
         """
+        Union of `Invoice` and `Receipt`.
+
         :param api_prediction: Raw prediction from HTTP response
         :param input_file: Input object
-        :param locale: locale value for creating FinancialDocument object from scratch
-        :param total_incl: total_incl value for creating FinancialDocument object from scratch
-        :param total_excl: total_excl value for creating FinancialDocument object from scratch
-        :param date: date value for creating FinancialDocument object from scratch
-        :param invoice_number: invoice_number value for creating FinancialDocument object from scratch
-        :param due_date: due_date value for creating FinancialDocument object from scratch
-        :param taxes: taxes value for creating FinancialDocument object from scratch
-        :param merchant_name: merchant_name value for creating FinancialDocument object from scratch
-        :param payment_details: payment_details value for creating FinancialDocument object from scratch
-        :param company_number: company_number value for creating FinancialDocument object from scratch
-        :param vat_number: vat_number value for creating FinancialDocument object from scratch
-        :param orientation: orientation value for creating FinancialDocument object from scratch
-        :param total_tax: total_tax value for creating FinancialDocument object from scratch
-        :param time: time value for creating FinancialDocument object from scratch
         :param page_n: Page number for multi pages pdf input
         """
-        # Invoke Document constructor
-        super().__init__(
-            input_file=input_file,
-            document_type=document_type,
-            api_prediction=api_prediction,
-            page_n=page_n,
-        )
-
-        self.locale = None
         self.total_incl = None
         self.total_excl = None
         self.date = None
@@ -73,97 +38,33 @@ class FinancialDocument(Document):
         self.payment_details = None
         self.company_number = None
         self.vat_number = None
-        self.orientation = None
         self.total_tax = None
         self.time = None
+        self.supplier_address = None
+        self.customer_name = None
+        self.customer_company_registration = None
+        self.customer_address = None
 
-        if api_prediction is not None:
-            self.build_from_api_prediction(api_prediction, input_file, page_n=page_n)
-        else:
-            self.orientation = Orientation(
-                {"value": orientation}, value_key="value", page_n=page_n
-            )
-            self.locale = Locale({"value": locale}, value_key="value", page_n=page_n)
-            self.date = Date({"value": date}, value_key="value", page_n=page_n)
-            self.due_date = Date({"value": due_date}, value_key="value", page_n=page_n)
-            if taxes is not None:
-                self.taxes = [
-                    Tax(
-                        {"value": t[0], "rate": t[1]},
-                        page_n=page_n,
-                        value_key="value",
-                        rate_key="rate",
-                    )
-                    for t in taxes
-                ]
-            self.total_incl = Amount(
-                {"value": total_incl}, value_key="value", page_n=page_n
-            )
-            self.total_excl = Amount(
-                {"value": total_excl}, value_key="value", page_n=page_n
-            )
-            self.merchant_name = Field(
-                {"value": merchant_name}, value_key="value", page_n=page_n
-            )
-            self.time = Field({"value": time}, value_key="value", page_n=page_n)
-            self.total_tax = Amount(
-                {"value": total_tax}, value_key="value", page_n=page_n
-            )
-            self.vat_number = Field(
-                {"value": vat_number}, value_key="value", page_n=page_n
-            )
-            self.invoice_number = Field(
-                {"value": invoice_number}, value_key="value", page_n=page_n
-            )
-            self.payment_details = Field(
-                {"value": payment_details}, value_key="value", page_n=page_n
-            )
-            self.company_number = Field(
-                {"value": company_number}, value_key="value", page_n=page_n
-            )
+        # need this for building from prediction
+        self.input_file = input_file
 
-        # Run checks
-        self._checklist()
-
-        # Reconstruct extra fields
-        self._reconstruct()
-
-    @staticmethod
-    def get_document_config():
-        """:return: the configuration for financial document"""
-        return DocumentConfig(
-            {
-                "constructor": FinancialDocument,
-                "endpoints": [
-                    Endpoint(
-                        owner="mindee",
-                        url_name="invoices",
-                        version="2",
-                        key_name="invoice",
-                    ),
-                    Endpoint(
-                        owner="mindee",
-                        url_name="expense_receipts",
-                        version="3",
-                        key_name="receipt",
-                    ),
-                ],
-                "document_type": "financial_doc",
-                "singular_name": "financial_doc",
-                "plural_name": "financial_docs",
-            },
-            api_type=API_TYPE_OFF_THE_SHELF,
+        super().__init__(
+            input_file=input_file,
+            document_type=document_type,
+            api_prediction=api_prediction,
+            page_n=page_n,
         )
 
-    def build_from_api_prediction(self, api_prediction, input_file, page_n=0):
+    def build_from_api_prediction(self, api_prediction, page_n=0):
         """
+        Build the document from an API response JSON.
+
         :param api_prediction: Raw prediction from HTTP response
-        :param input_file: Input object
         :param page_n: Page number for multi pages pdf input
         :return: (void) set the object attributes with api prediction values
         """
         if "invoice_number" in api_prediction.keys():
-            invoice = Invoice(api_prediction, input_file, page_n=page_n)
+            invoice = Invoice(api_prediction, self.input_file, page_n=page_n)
             self.locale = invoice.locale
             self.total_incl = invoice.total_incl
             self.total_excl = invoice.total_excl
@@ -177,8 +78,12 @@ class FinancialDocument(Document):
             self.orientation = invoice.orientation
             self.total_tax = invoice.total_tax
             self.time = Field({"value": None, "confidence": 0.0})
+            self.supplier_address = invoice.supplier_address
+            self.customer_name = invoice.customer_name
+            self.customer_company_registration = invoice.customer_company_registration
+            self.customer_address = invoice.customer_address
         else:
-            receipt = Receipt(api_prediction, input_file, page_n=page_n)
+            receipt = Receipt(api_prediction, self.input_file, page_n=page_n)
             self.orientation = receipt.orientation
             self.date = receipt.date
             self.due_date = receipt.date
@@ -192,6 +97,12 @@ class FinancialDocument(Document):
             self.invoice_number = Field({"value": None, "confidence": 0.0})
             self.payment_details = []
             self.company_number = []
+            self.supplier_address = Field({"value": None, "confidence": 0.0})
+            self.customer_name = Field({"value": None, "confidence": 0.0})
+            self.customer_company_registration = Field(
+                {"value": None, "confidence": 0.0}
+            )
+            self.customer_address = Field({"value": None, "confidence": 0.0})
 
     def __str__(self) -> str:
         return (
@@ -203,6 +114,10 @@ class FinancialDocument(Document):
             "Date: %s\n"
             "Invoice due date: %s\n"
             "Supplier name: %s\n"
+            f"Supplier address: {self.supplier_address}\n"
+            f"Customer name: {self.customer_name}\n"
+            f"Customer company registration: {self.customer_company_registration}\n"
+            f"Customer address: {self.customer_address}\n"
             "Taxes: %s\n"
             "Total taxes: %s\n"
             "----------------------"
@@ -222,7 +137,8 @@ class FinancialDocument(Document):
     @staticmethod
     def request(endpoints: List[Endpoint], input_file, include_words=False):
         """
-        Make request to expense_receipts endpoint
+        Make request to prediction endpoint.
+
         :param input_file: Input object
         :param endpoints: Endpoints config
         :param include_words: Include Mindee vision words in http_response
@@ -232,23 +148,17 @@ class FinancialDocument(Document):
             index = 0
         else:
             index = 1
-        return make_api_request(
-            endpoints[index].predict_url,
-            input_file,
-            endpoints[index].api_key,
-            include_words,
-        )
+        return endpoints[index].predict_request(input_file, include_words)
 
-    def _checklist(self):
-        """
-        :return: Set of validation rules
-        """
+    def _checklist(self) -> None:
+        """Set the validation rules."""
         self.checklist = {"taxes_match_total_incl": self.__taxes_match_total_incl()}
 
     # Checks
-    def __taxes_match_total_incl(self):
+    def __taxes_match_total_incl(self) -> bool:
         """
-        Check invoice rule of matching between taxes and total_incl
+        Check invoice rule of matching between taxes and total_incl.
+
         :return: True if rule matches, False otherwise
         """
         # Check taxes and total_incl exist
