@@ -2,14 +2,13 @@ from typing import List, Optional
 
 from mindee.documents.base import Document
 from mindee.fields import Field
-from mindee.fields.date import Date
 from mindee.fields.amount import Amount
+from mindee.fields.date import Date
 from mindee.fields.locale import Locale
 from mindee.fields.orientation import Orientation
 from mindee.fields.payment_details import PaymentDetails
 from mindee.fields.tax import Tax
-from mindee.http import make_api_request, API_TYPE_OFF_THE_SHELF, Endpoint
-from mindee.document_config import DocumentConfig
+from mindee.http import Endpoint
 
 
 class Invoice(Document):
@@ -21,6 +20,10 @@ class Invoice(Document):
     due_date: Date
     taxes: List[Tax] = []
     supplier: Field
+    supplier_address: Field
+    customer_name: Field
+    customer_company_registration: Field
+    customer_address: Field
     payment_details: List[PaymentDetails] = []
     company_number: List[Field] = []
     total_tax: Amount
@@ -31,39 +34,16 @@ class Invoice(Document):
         self,
         api_prediction=None,
         input_file=None,
-        locale=None,
-        total_incl=None,
-        total_excl=None,
-        invoice_date=None,
-        invoice_number=None,
-        due_date=None,
-        taxes=None,
-        supplier=None,
-        payment_details=None,
-        company_number=None,
-        orientation=None,
-        total_tax=None,
         page_n=0,
         document_type="invoice",
     ):
         """
+        Invoice document.
+
         :param api_prediction: Raw prediction from HTTP response
         :param input_file: Input object
-        :param locale: locale value for creating Invoice object from scratch
-        :param total_incl: total_incl value for creating Invoice object from scratch
-        :param total_excl: total_excl value for creating Invoice object from scratch
-        :param invoice_date: invoice_date value for creating Invoice object from scratch
-        :param invoice_number: invoice_number value for creating Invoice object from scratch
-        :param due_date: due_date value for creating Invoice object from scratch
-        :param taxes: taxes value for creating Invoice object from scratch
-        :param supplier: supplier value for creating Invoice object from scratch
-        :param payment_details: payment_details value for creating Invoice object from scratch
-        :param company_number: company_number value for creating Invoice object from scratch
-        :param orientation: orientation value for creating Invoice object from scratch
-        :param total_tax: total_tax value for creating Invoice object from scratch
         :param page_n: Page number for multi pages pdf input
         """
-        # Invoke Document constructor
         super().__init__(
             input_file=input_file,
             document_type=document_type,
@@ -71,82 +51,17 @@ class Invoice(Document):
             page_n=page_n,
         )
 
-        if api_prediction is not None:
-            self.build_from_api_prediction(api_prediction, page_n=page_n)
-        else:
-            self.locale = Locale({"value": locale}, value_key="value", page_n=page_n)
-            self.total_incl = Amount(
-                {"value": total_incl}, value_key="value", page_n=page_n
-            )
-            self.invoice_date = Date(
-                {"value": invoice_date}, value_key="value", page_n=page_n
-            )
-            self.due_date = Date({"value": due_date}, value_key="value", page_n=page_n)
-            self.supplier = Field({"value": supplier}, value_key="value", page_n=page_n)
-            if taxes is not None:
-                self.taxes = [
-                    Tax(
-                        {"value": t[0], "rate": t[1]},
-                        page_n=page_n,
-                        value_key="value",
-                        rate_key="rate",
-                    )
-                    for t in taxes
-                ]
-            self.orientation = Orientation(
-                {"value": orientation}, value_key="value", page_n=page_n
-            )
-            self.total_tax = Amount(
-                {"value": total_tax}, value_key="value", page_n=page_n
-            )
-            self.total_excl = Amount(
-                {"value": total_excl}, value_key="value", page_n=page_n
-            )
-            self.invoice_number = Field(
-                {"value": invoice_number}, value_key="value", page_n=page_n
-            )
-            self.payment_details = [
-                PaymentDetails(
-                    {"value": payment_details}, value_key="value", page_n=page_n
-                )
-            ]
-            self.company_number = [
-                Field({"value": company_number}, value_key="value", page_n=page_n)
-            ]
-
-        # Run checks
-        self._checklist()
-
-        # Reconstruct extra fields
-        self._reconstruct()
-
-    @staticmethod
-    def get_document_config() -> DocumentConfig:
-        """:return: the configuration for invoice"""
-        return DocumentConfig(
-            {
-                "constructor": Invoice,
-                "endpoints": [
-                    Endpoint(
-                        owner="mindee",
-                        url_name="invoices",
-                        version="2",
-                        key_name="invoice",
-                    )
-                ],
-                "document_type": "invoice",
-                "singular_name": "invoice",
-                "plural_name": "invoices",
-            },
-            api_type=API_TYPE_OFF_THE_SHELF,
-        )
-
     def build_from_api_prediction(self, api_prediction: dict, page_n=0):
         """
+        Build the object from the prediction API JSON.
+
         :param api_prediction: Raw prediction from HTTP response
         :param page_n: Page number for multi pages pdf input
         :return: (void) set the object attributes with api prediction values
         """
+        if page_n is not None:
+            self.orientation = Orientation(api_prediction["orientation"], page_n=page_n)
+
         self.company_number = [
             Field(company_reg, extra_fields={"type"}, page_n=page_n)
             for company_reg in api_prediction["company_registration"]
@@ -161,9 +76,14 @@ class Invoice(Document):
         self.locale = Locale(
             api_prediction["locale"], value_key="language", page_n=page_n
         )
-        if str(page_n) != "-1":
-            self.orientation = Orientation(api_prediction["orientation"], page_n=page_n)
         self.supplier = Field(api_prediction["supplier"], page_n=page_n)
+        self.supplier_address = Field(api_prediction["supplier_address"], page_n=page_n)
+        self.customer_name = Field(api_prediction["customer"], page_n=page_n)
+        self.customer_company_registration = Field(
+            api_prediction["customer_company_registration"], page_n=page_n
+        )
+        self.customer_address = Field(api_prediction["customer_address"], page_n=page_n)
+
         self.taxes = [
             Tax(tax_prediction, page_n=page_n, value_key="value")
             for tax_prediction in api_prediction["taxes"]
@@ -185,20 +105,24 @@ class Invoice(Document):
     def __str__(self) -> str:
         company_numbers = "; ".join([str(n.value) for n in self.company_number])
         payments = ", ".join([str(p) for p in self.payment_details])
-        taxes = ", ".join([f"{t.value} {t.rate}%" for t in self.taxes])
+        taxes = ", ".join(f"{t}" for t in self.taxes)
         return (
             "-----Invoice data-----\n"
             f"Filename: {self.filename}\n"
-            f"Invoice number: {self.invoice_number.value}\n"
-            f"Total amount including taxes: {self.total_incl.value}\n"
-            f"Total amount excluding taxes: {self.total_excl.value}\n"
-            f"Invoice date: {self.invoice_date.value}\n"
-            f"Invoice due date: {self.due_date.value}\n"
-            f"Supplier name: {self.supplier.value}\n"
+            f"Invoice number: {self.invoice_number}\n"
+            f"Total amount including taxes: {self.total_incl}\n"
+            f"Total amount excluding taxes: {self.total_excl}\n"
+            f"Invoice date: {self.invoice_date}\n"
+            f"Invoice due date: {self.due_date}\n"
+            f"Supplier name: {self.supplier}\n"
+            f"Supplier address: {self.supplier_address}\n"
+            f"Customer name: {self.customer_name}\n"
+            f"Customer company registration: {self.customer_company_registration}\n"
+            f"Customer address: {self.customer_address}\n"
             f"Payment details: {payments}\n"
             f"Company numbers: {company_numbers}\n"
             f"Taxes: {taxes}\n"
-            f"Total taxes: {self.total_tax.value}\n"
+            f"Total taxes: {self.total_tax}\n"
             f"Locale: {self.locale}\n"
             "----------------------"
         )
@@ -206,38 +130,34 @@ class Invoice(Document):
     @staticmethod
     def request(endpoints: List[Endpoint], input_file, include_words=False):
         """
-        Make request to expense_receipts endpoint
+        Make request to prediction endpoint.
+
         :param input_file: Input object
         :param endpoints: Endpoints config
         :param include_words: Include Mindee vision words in http_response
         """
-        return make_api_request(
-            endpoints[0].predict_url, input_file, endpoints[0].api_key, include_words
-        )
+        return endpoints[0].predict_request(input_file, include_words)
 
-    def _reconstruct(self):
-        """
-        Call fields reconstruction methods
-        """
+    def _reconstruct(self) -> None:
+        """Call fields reconstruction methods."""
         self.__reconstruct_total_tax_from_tax_lines()
         self.__reconstruct_total_excl_from_tcc_and_taxes()
         self.__reconstruct_total_incl_from_taxes_plus_excl()
         self.__reconstruct_total_tax_from_incl_and_excl()
 
-    def _checklist(self):
-        """
-        Call check methods
-        """
+    def _checklist(self) -> None:
+        """Call check methods."""
         self.checklist = {
             "taxes_match_total_incl": self.__taxes_match_total_incl(),
             "taxes_match_total_excl": self.__taxes_match_total_excl(),
-            "taxes_plus_total_excl_match_total_incl": self.__taxes_plus_total_excl_match_total_incl(),
+            "taxes_plus_total_excl_match_total_incl": self.__taxes_plus_total_excl_match_total_incl(),  # pylint: disable=line-too-long
         }
 
     # Checks
     def __taxes_match_total_incl(self) -> bool:
         """
-        Check invoice rule of matching between taxes and total_incl
+        Check invoice matching rule between taxes and total_incl.
+
         :return: True if rule matches, False otherwise
         """
         # Ensure taxes and total_incl exist
@@ -271,9 +191,10 @@ class Invoice(Document):
             return True
         return False
 
-    def __taxes_match_total_excl(self):
+    def __taxes_match_total_excl(self) -> bool:
         """
-        Check invoice rule of matching between taxes and total_excl
+        Check invoice matching rule between taxes and total_excl.
+
         :return: True if rule matches, False otherwise
         """
         # Check taxes and total excl exist
@@ -308,9 +229,11 @@ class Invoice(Document):
             return True
         return False
 
-    def __taxes_plus_total_excl_match_total_incl(self):
+    def __taxes_plus_total_excl_match_total_incl(self) -> bool:
         """
-        Check invoice rule of matching : sum(taxes) + total_excluding_taxes = total_including_taxes
+        Check invoice matching rule.
+
+        Rule is: sum(taxes) + total_excluding_taxes = total_including_taxes
         :return: True if rule matches, False otherwise
         """
         # Check total_tax, total excl and total incl exist
@@ -324,7 +247,8 @@ class Invoice(Document):
         # Reconstruct total_incl
         total_vat = 0
         for tax in self.taxes:
-            total_vat += tax.value
+            if tax.value is not None:
+                total_vat += tax.value
         reconstructed_total = total_vat + self.total_excl.value
 
         # Sanity check
@@ -346,11 +270,13 @@ class Invoice(Document):
         return False
 
     # Reconstruct
-    def __reconstruct_total_incl_from_taxes_plus_excl(self):
+    def __reconstruct_total_incl_from_taxes_plus_excl(self) -> None:
         """
-        Set self.total_incl with Amount object
+        Set self.total_incl with Amount object.
+
         The total_incl Amount value is the sum of total_excl and sum of taxes
-        The total_incl Amount confidence is the product of self.taxes probabilities multiplied by total_excl confidence
+        The total_incl Amount confidence is the product of self.taxes probabilities
+            multiplied by total_excl confidence
         """
         # Check total_tax, total excl exist and total incl is not set
         if (
@@ -370,11 +296,13 @@ class Invoice(Document):
             }
             self.total_incl = Amount(total_incl, value_key="value", reconstructed=True)
 
-    def __reconstruct_total_excl_from_tcc_and_taxes(self):
+    def __reconstruct_total_excl_from_tcc_and_taxes(self) -> None:
         """
-        Set self.total_excl with Amount object
+        Set self.total_excl with Amount object.
+
         The total_excl Amount value is the difference between total_incl and sum of taxes
-        The total_excl Amount confidence is the product of self.taxes probabilities multiplied by total_incl confidence
+        The total_excl Amount confidence is the product of self.taxes probabilities
+            multiplied by total_incl confidence
         """
         # Check total_tax, total excl and total incl exist
         if (
@@ -394,9 +322,10 @@ class Invoice(Document):
             }
             self.total_excl = Amount(total_excl, value_key="value", reconstructed=True)
 
-    def __reconstruct_total_tax_from_tax_lines(self):
+    def __reconstruct_total_tax_from_tax_lines(self) -> None:
         """
-        Set self.total_tax with Amount object
+        Set self.total_tax with Amount object.
+
         The total_tax Amount value is the sum of all self.taxes value
         The total_tax Amount confidence is the product of self.taxes probabilities
         """
@@ -412,9 +341,10 @@ class Invoice(Document):
                     total_tax, value_key="value", reconstructed=True
                 )
 
-    def __reconstruct_total_tax_from_incl_and_excl(self):
+    def __reconstruct_total_tax_from_incl_and_excl(self) -> None:
         """
-        Set self.total_tax with Amount object
+        Set self.total_tax with Amount object.
+
         Check if the total tax was already set
         If not, set thta total tax amount to the diff of incl and excl
         """
