@@ -1,11 +1,10 @@
-from typing import List
 from datetime import datetime
+from typing import List
 
 from mindee.documents.base import Document
 from mindee.fields import Field
 from mindee.fields.date import Date
-from mindee.http import make_api_request, API_TYPE_OFF_THE_SHELF, Endpoint
-from mindee.document_config import DocumentConfig
+from mindee.http import Endpoint
 
 
 class Passport(Document):
@@ -27,41 +26,16 @@ class Passport(Document):
         self,
         api_prediction=None,
         input_file=None,
-        country=None,
-        id_number=None,
-        birth_date=None,
-        expiry_date=None,
-        issuance_date=None,
-        birth_place=None,
-        gender=None,
-        surname=None,
-        mrz1=None,
-        mrz2=None,
-        given_names=None,
-        mrz=None,
-        full_name=None,
         page_n=0,
         document_type="passport",
     ):
         """
+        Passport document.
+
         :param api_prediction: Raw prediction from HTTP response
         :param input_file: Input object
-        :param country: country value for creating Passport object from scratch
-        :param id_number: id_number value for creating Passport object from scratch
-        :param birth_date: birth_date value for creating Passport object from scratch
-        :param expiry_date: expiry_date value for creating Passport object from scratch
-        :param issuance_date: issuance_date value for creating Passport object from scratch
-        :param birth_place: birth_place value for creating Passport object from scratch
-        :param gender: gender value for creating Passport object from scratch
-        :param surname: surname value for creating Passport object from scratch
-        :param mrz1: mrz1 value for creating Passport object from scratch
-        :param mrz2: mrz2 value for creating Passport object from scratch
-        :param given_names: given_names value for creating Passport object from scratch
-        :param mrz: mrz value for creating Passport object from scratch
-        :param full_name: full_name value for creating Passport object from scratch
         :param page_n: Page number for multi pages pdf input
         """
-        # Invoke Document constructor
         super().__init__(
             input_file=input_file,
             document_type=document_type,
@@ -69,63 +43,10 @@ class Passport(Document):
             page_n=page_n,
         )
 
-        if api_prediction is not None:
-            self.build_from_api_prediction(api_prediction, page_n=page_n)
-        else:
-            self.country = Field({"value": country}, value_key="value", page_n=page_n)
-            self.id_number = Field(
-                {"value": id_number}, value_key="value", page_n=page_n
-            )
-            self.birth_date = Date(
-                {"value": birth_date}, value_key="value", page_n=page_n
-            )
-            self.expiry_date = Date(
-                {"value": expiry_date}, value_key="value", page_n=page_n
-            )
-            self.issuance_date = Date(
-                {"value": issuance_date}, value_key="value", page_n=page_n
-            )
-            self.birth_place = Field(
-                {"value": birth_place}, value_key="value", page_n=page_n
-            )
-            self.gender = Field({"value": gender}, value_key="value", page_n=page_n)
-            self.surname = Field({"value": surname}, value_key="value", page_n=page_n)
-            self.mrz1 = Field({"value": mrz1}, value_key="value", page_n=page_n)
-            self.mrz2 = Field({"value": mrz2}, value_key="value", page_n=page_n)
-            if given_names is not None:
-                self.given_names = [
-                    Field({"value": g}, value_key="value", page_n=page_n)
-                    for g in given_names
-                ]
-            self.mrz = Field({"value": mrz}, value_key="value", page_n=page_n)
-            self.full_name = Field(
-                {"value": full_name}, value_key="value", page_n=page_n
-            )
-
-        # Run checks
-        self._checklist()
-
-        # Reconstruct extra fields
-        self._reconstruct()
-
-    @staticmethod
-    def get_document_config() -> DocumentConfig:
-        """:return: the configuration for passport"""
-        return DocumentConfig(
-            {
-                "constructor": Passport,
-                "endpoints": [
-                    Endpoint(owner="mindee", url_name="passport", version="1")
-                ],
-                "document_type": "passport",
-                "singular_name": "passport",
-                "plural_name": "passports",
-            },
-            api_type=API_TYPE_OFF_THE_SHELF,
-        )
-
     def build_from_api_prediction(self, api_prediction, page_n=0):
         """
+        Build the document from an API response JSON.
+
         :param api_prediction: Raw prediction from HTTP response
         :param page_n: Page number for multi pages pdf input
         :return: (void) set the object attributes with api prediction values
@@ -159,53 +80,52 @@ class Passport(Document):
         return (
             "-----Passport data-----\n"
             f"Filename: {self.filename}\n"
-            f"Full name: {self.full_name.value}\n"
+            f"Full name: {self.full_name}\n"
             f"Given names: {given_names}\n"
-            f"Surname: {self.surname.value}\n"
-            f"Country: {self.country.value}\n"
-            f"ID Number: {self.id_number.value}\n"
-            f"Issuance date: {self.issuance_date.value}\n"
-            f"Birth date: {self.birth_date.value}\n"
-            f"Expiry date: {self.expiry_date.value}\n"
-            f"MRZ 1: {self.mrz1.value}\n"
-            f"MRZ 2: {self.mrz2.value}\n"
-            f"MRZ: {self.mrz.value}\n"
+            f"Surname: {self.surname}\n"
+            f"Country: {self.country}\n"
+            f"ID Number: {self.id_number}\n"
+            f"Issuance date: {self.issuance_date}\n"
+            f"Birth date: {self.birth_date}\n"
+            f"Expiry date: {self.expiry_date}\n"
+            f"MRZ 1: {self.mrz1}\n"
+            f"MRZ 2: {self.mrz2}\n"
+            f"MRZ: {self.mrz}\n"
             "----------------------"
         )
 
-    def is_expired(self):
+    def is_expired(self) -> bool:
         """
+        Check the passport's validity.
+
         :return: True if the passport is expired, False otherwise
         """
+        if not self.expiry_date.date_object:
+            return False
         return self.expiry_date.date_object < datetime.date(datetime.now())
 
     @staticmethod
     def request(endpoints: List[Endpoint], input_file, include_words=False):
         """
-        Make request to expense_receipts endpoint
+        Make request to prediction endpoint.
+
         :param input_file: Input object
         :param endpoints: Endpoints config
         :param include_words: Include Mindee vision words in http_response
         """
         if include_words:
-            raise Exception(
-                "invlude_words parameter cannot be set to True for passport API"
+            raise ValueError(
+                "include_words parameter cannot be set to True for passport API"
             )
-        return make_api_request(
-            endpoints[0].predict_url, input_file, endpoints[0].api_key, include_words
-        )
+        return endpoints[0].predict_request(input_file, include_words)
 
-    def _reconstruct(self):
-        """
-        Call fields reconstruction methods
-        """
+    def _reconstruct(self) -> None:
+        """Call fields reconstruction methods."""
         self.__reconstruct_mrz()
         self.__reconstruct_full_name()
 
-    def _checklist(self, *args):
-        """
-        Call check methods
-        """
+    def _checklist(self) -> None:
+        """Call check methods."""
         self.checklist = {
             "mrz_id_number_checksum": self.__mrz_id_number_checksum(),
             "mrz_date_of_birth_checksum": self.__mrz_date_of_birth_checksum(),
@@ -216,9 +136,11 @@ class Passport(Document):
         }
 
     # Checks
-    def __mrz__checksum(self):
+    def __mrz__checksum(self) -> bool:
         """
-        :return: True if the all MRZ checksums are validated, False otherwise
+        Validate all MRZ checksums.
+
+        :return: True if all are valid, False otherwise
         """
         return (
             self.__mrz_id_number_checksum()
@@ -230,7 +152,9 @@ class Passport(Document):
 
     def __mrz_id_number_checksum(self) -> bool:
         """
-        :return: True if id number MRZ checksum is validated, False otherwise
+        Validate the ID number's MRZ checksum.
+
+        :return: True if valid, False otherwise
         """
         if self.mrz2.value is None:
             return False
@@ -241,7 +165,9 @@ class Passport(Document):
 
     def __mrz_date_of_birth_checksum(self) -> bool:
         """
-        :return: True if date of birth MRZ checksum is validated, False otherwise
+        Validate the date of birth's MRZ checksum.
+
+        :return: True if valid, False otherwise
         """
         if self.mrz2.value is None:
             return False
@@ -252,7 +178,9 @@ class Passport(Document):
 
     def __mrz_expiration_date_checksum(self) -> bool:
         """
-        :return: True if expiry date MRZ checksum is validated, False otherwise
+        Validate the expiry date's MRZ checksum.
+
+        :return: True if valid, False otherwise
         """
         if self.mrz2.value is None:
             return False
@@ -263,15 +191,19 @@ class Passport(Document):
 
     def __mrz_personal_number_checksum(self) -> bool:
         """
-        :return: True if personal number MRZ checksum is validated, False otherwise
+        Validate the personal number's MRZ checksum.
+
+        :return: True if valid, False otherwise
         """
         if self.mrz2.value is None:
             return False
         return Passport.check_sum(self.mrz2.value[28:42]) == self.mrz2.value[42]
 
-    def __mrz_last_name_checksum(self):
+    def __mrz_last_name_checksum(self) -> bool:
         """
-        :return: True if last url_name MRZ checksum is validated, False otherwise
+        Validate the last name's MRZ checksum.
+
+        :return: True if valid, False otherwise
         """
         if self.mrz2.value is None:
             return False
@@ -288,6 +220,8 @@ class Passport(Document):
     @staticmethod
     def check_sum(to_check: str) -> str:
         """
+        Validate the checksum.
+
         https://en.wikipedia.org/wiki/Machine-readable_passport
         :param to_check: string
         :return: checksum value for string s
@@ -312,9 +246,10 @@ class Passport(Document):
         return str(checker % 10)
 
     # Reconstruct
-    def __reconstruct_mrz(self):
+    def __reconstruct_mrz(self) -> None:
         """
-        Set self.mrz with Field object
+        Set self.mrz with Field object.
+
         The mrz Field value is the concatenation of mrz1 and mr2
         The mrz Field confidence is the product of mrz1 and mrz2 probabilities
         """
@@ -331,11 +266,14 @@ class Passport(Document):
             }
             self.mrz = Field(mrz, reconstructed=True)
 
-    def __reconstruct_full_name(self):
+    def __reconstruct_full_name(self) -> None:
         """
-        Set self.full_name with Field object
-        The full_name Field value is the concatenation of first given url_name and last url_name
-        The full_name Field confidence is the product of first given url_name and last url_name probabilities
+        Set self.full_name with Field object.
+
+        The full_name Field value is the concatenation of:
+            first given url_name and last url_name
+        The full_name Field confidence is the product of:
+            first given url_name and last url_name probabilities
         """
         if (
             self.surname.value is not None
