@@ -1,4 +1,4 @@
-from typing import Optional, Any, List, Dict
+from typing import Any, Dict, List, Optional
 
 
 class Field:
@@ -15,11 +15,14 @@ class Field:
         page_n=None,
     ):
         """
+        Base field object.
+
         :param abstract_prediction: Prediction object from HTTP response
         :param value_key: Key to use in the abstract_prediction dict
         :param reconstructed: Bool for reconstructed object (not extracted in the API)
-        :param page_n: Page number for multi pages pdf
-        :param extra_fields: extra field to get from the abstract_prediction and to set as attribute of the Field
+        :param page_n: Page number for multi pages PDF
+        :param extra_fields: extra field to get from the abstract_prediction and
+            to set as attribute of the Field
         """
         self.page_n = page_n
 
@@ -47,32 +50,27 @@ class Field:
 
         self.reconstructed = reconstructed
 
-    def __eq__(self, other):
-        if self.value is None and other.value is None:
-            return True
-        if self.value is None or other.value is None:
-            return False
-        if isinstance(self.value, str):
-            return self.value.lower() == other.value.lower()
-        return self.value == other.value
-
     @staticmethod
     def compare_arrays(array1: list, array2: list, attr="value") -> bool:
         """
+        Check that all elements are present in both arrays.
+
         :param array1: Array of Fields
         :param array2: Array of Fields
         :param attr: Attribute to compare
         :return: True if all elements in array1 exist in array2, False otherwise
         """
-        set1 = set([getattr(f1, attr) for f1 in array1])
-        set2 = set([getattr(f2, attr) for f2 in array2])
+        set1 = {getattr(f1, attr) for f1 in array1}
+        set2 = {getattr(f2, attr) for f2 in array2}
         return set1 == set2
 
     @staticmethod
     def array_confidence(array: list) -> float:
         """
+        Multiply all Field's confidence in the array.
+
         :param array: Array of fields
-        :return: Product of all the Fields confidence in the array
+        :return: Product as float
         """
         product = 1
         for field in array:
@@ -85,8 +83,10 @@ class Field:
     @staticmethod
     def array_sum(array: list) -> float:
         """
+        Add all the Field values in the array.
+
         :param array: Array of fields
-        :return: Sum of all the Fields values in the array
+        :return: Sum as float.
         """
         array_sum = 0
         for field in array:
@@ -95,3 +95,17 @@ class Field:
             except (AttributeError, TypeError):
                 return 0.0
         return float(array_sum)
+
+    def __eq__(self, other) -> bool:
+        if self.value is None and other.value is None:
+            return True
+        if self.value is None or other.value is None:
+            return False
+        if isinstance(self.value, str):
+            return self.value.lower() == other.value.lower()
+        return self.value == other.value
+
+    def __str__(self) -> str:
+        if self.value:
+            return f"{self.value}"
+        return ""
