@@ -1,11 +1,12 @@
+import base64
 import io
 import os
-import base64
-from typing import Optional, BinaryIO
 from mimetypes import guess_type
+from typing import BinaryIO, Optional
 
 import pikepdf
 
+from mindee.logger import logger
 
 ALLOWED_EXTENSIONS = [
     "image/png",
@@ -49,24 +50,29 @@ class InputDocument:
                     )
             if self.is_pdf_empty():
                 raise AssertionError(f"PDF pages are empty in: {self.filename}")
+        logger.debug("Loaded new document '%s' from %s", self.filename, self.input_type)
 
-    def count_pdf_pages(self):
+    def count_pdf_pages(self) -> int:
         """
-        :return: Number of pages in the Input file for pdfs
+        Count the pages in the PDF.
+
+        :return: the number of pages.
         """
         self.file_object.seek(0)
         with pikepdf.open(self.file_object) as pdf:
             return len(pdf.pages)
 
-    def merge_pdf_pages(self, pages_number):
+    def merge_pdf_pages(self, page_numbers: list) -> None:
         """
-        :param pages_number: List of pages number to use for merging in the original pdf
+        Create a new PDF from pages.
+
+        :param page_numbers: List of pages number to use for merging in the original PDF.
         :return: (void) Set the Input.file with the reconstructed pdf stream
         """
         self.file_object.seek(0)
         new_pdf = pikepdf.Pdf.new()
         with pikepdf.open(self.file_object) as pdf:
-            for page_n in pages_number:
+            for page_n in page_numbers:
                 new_pdf.pages.append(pdf.pages[page_n])
         self.file_object.close()
         self.file_object = io.BytesIO()
@@ -74,6 +80,8 @@ class InputDocument:
 
     def is_pdf_empty(self) -> bool:
         """
+        Check if the PDF is empty.
+
         :return: (void) Check if the document contain only empty pages
         """
         self.file_object.seek(0)
@@ -97,9 +105,11 @@ class InputDocument:
                     return False
             return True
 
-    def check_pdf_open(self):
+    def check_pdf_open(self) -> None:
         """
-        :return: (void) Check if the document can be opened using pikepdf
+        Check if the document can be opened using pikepdf.
+
+        :return: None
         """
         self.file_object.seek(0)
         try:
@@ -116,6 +126,8 @@ class FileDocument(InputDocument):
         n_pdf_pages=3,
     ):
         """
+        Input document from a Python binary file object.
+
         :param file: FileIO object
         :param cut_pdf: Automatically reconstruct pdf with more than 4 pages
         """
@@ -140,6 +152,8 @@ class PathDocument(InputDocument):
         n_pdf_pages=3,
     ):
         """
+        Input document from a path.
+
         :param filepath: Path to open
         :param cut_pdf: Automatically reconstruct pdf with more than 4 pages
         """
@@ -163,6 +177,8 @@ class BytesDocument(InputDocument):
         n_pdf_pages=3,
     ):
         """
+        Input document from raw bytes (no buffer).
+
         :param raw_bytes: Raw data as bytes
         :param filename: File name of the input
         :param cut_pdf: Automatically reconstruct pdf with more than 4 pages
@@ -188,6 +204,8 @@ class Base64Document(InputDocument):
         n_pdf_pages=3,
     ):
         """
+        Input document from a base64 encoded string.
+
         :param base64_string: Raw data as a base64 encoded string
         :param filename: File name of the input
         :param cut_pdf: Automatically reconstruct pdf with more than N pages
