@@ -1,9 +1,13 @@
-import pytest
 import json
+
+import pytest
+
 from mindee import Client
-from mindee.response import format_response
-from mindee.inputs import PathDocument
 from mindee.documents.base import Document
+from mindee.inputs import PathDocument
+from mindee.response import format_response
+from tests.documents.test_invoice import INVOICE_FILE_PATH
+from tests.documents.test_receipt import RECEIPT_FILE_PATH
 
 
 @pytest.fixture
@@ -31,35 +35,29 @@ def dummy_config():
 
 
 def test_constructor(dummy_file_input):
-    document = Document(
-        dummy_file_input, document_type="receipt", api_prediction={}, page_n=0
-    )
-    assert document.checklist == {}
     with pytest.raises(NotImplementedError):
-        document.request([], "")
-    with pytest.raises(NotImplementedError):
-        document._checklist()
+        Document(dummy_file_input, document_type="receipt", api_prediction={}, page_n=0)
 
 
 # Invoice tests
 
 
 def test_response_wrapper_invoice(dummy_file_input, dummy_config):
-    response = json.load(open("./tests/data/invoices/v2/invoice.json"))
+    response = json.load(open(INVOICE_FILE_PATH))
     parsed_invoice = format_response(
         dummy_config[("mindee", "invoice")],
         response,
         "invoice",
         dummy_file_input,
     )
-    assert parsed_invoice.invoice.invoice_date.value == "2018-09-25"
+    assert parsed_invoice.invoice.invoice_date.value == "2020-02-17"
 
 
 # Receipt tests
 
 
 def test_response_wrapper_receipt(dummy_file_input, dummy_config):
-    response = json.load(open("./tests/data/expense_receipts/v3/receipt.json"))
+    response = json.load(open(RECEIPT_FILE_PATH))
     parsed_receipt = format_response(
         dummy_config[("mindee", "receipt")], response, "receipt", dummy_file_input
     )
@@ -69,10 +67,8 @@ def test_response_wrapper_receipt(dummy_file_input, dummy_config):
 # Financial document tests
 
 
-def test_response_wrapper_financial_document_with_receipt(
-    dummy_file_input, dummy_config
-):
-    response = json.load(open("./tests/data/expense_receipts/v3/receipt.json"))
+def test_response_wrapper_financial_doc_with_receipt(dummy_file_input, dummy_config):
+    response = json.load(open(RECEIPT_FILE_PATH))
     parsed_financial_doc = format_response(
         dummy_config[("mindee", "financial_doc")],
         response,
@@ -82,14 +78,12 @@ def test_response_wrapper_financial_document_with_receipt(
     assert parsed_financial_doc.financial_doc.date.value == "2016-02-26"
 
 
-def test_response_wrapper_financial_document_with_invoice(
-    dummy_file_input, dummy_config
-):
-    response = json.load(open("./tests/data/invoices/v2/invoice.json"))
+def test_response_wrapper_financial_doc_with_invoice(dummy_file_input, dummy_config):
+    response = json.load(open(INVOICE_FILE_PATH))
     parsed_financial_doc = format_response(
         dummy_config[("mindee", "financial_doc")],
         response,
         "financial",
         dummy_file_input,
     )
-    assert parsed_financial_doc.financial_doc.date.value == "2018-09-25"
+    assert parsed_financial_doc.financial_doc.date.value == "2020-02-17"
