@@ -1,43 +1,28 @@
 import json
+
 import pytest
+
 from mindee.documents.invoice import Invoice
 
+INVOICE_FILE_PATH = "./tests/data/invoices/v2/invoice.json"
+INVOICE_NA_FILE_PATH = "./tests/data/invoices/v2/invoice_all_na.json"
+
 
 @pytest.fixture
 def invoice_object():
-    json_repsonse = json.load(open("./tests/data/invoices/v2/invoice.json"))
-    return Invoice(json_repsonse["document"]["inference"]["pages"][0]["prediction"])
+    json_repsonse = json.load(open(INVOICE_FILE_PATH))
+    return Invoice(json_repsonse["document"]["inference"]["prediction"], page_n=None)
 
 
 @pytest.fixture
-def invoice_object_from_scratch():
-    return Invoice(
-        locale="fr",
-        total_incl=12,
-        total_excl=15,
-        invoice_date="2018-12-21",
-        invoice_number="001",
-        due_date="2019-01-01",
-        taxes={(1, 10), (2, 20)},
-        supplier="Amazon",
-        payment_details="1231456498799765",
-        company_number="asdqsdae",
-        orientation=0,
-        total_tax=3,
-    )
-
-
-@pytest.fixture
-def invoice_object_all_na():
-    json_repsonse = json.load(open("./tests/data/invoices/v2/invoice_all_na.json"))
-    return Invoice(json_repsonse["document"]["inference"]["pages"][0]["prediction"])
+def invoice_object_all_na(invoice_pred):
+    return Invoice(invoice_pred)
 
 
 @pytest.fixture
 def invoice_pred():
-    return json.load(open("./tests/data/invoices/v2/invoice_all_na.json"))["document"][
-        "inference"
-    ]["pages"][0]["prediction"]
+    invoice_json = json.load(open(INVOICE_NA_FILE_PATH))
+    return invoice_json["document"]["inference"]["pages"][0]["prediction"]
 
 
 # Technical tests
@@ -48,7 +33,7 @@ def test_constructor(invoice_object):
     assert invoice_object.checklist["taxes_plus_total_excl_match_total_incl"] is True
     assert invoice_object.total_tax.value == 97.98
     assert invoice_object.invoice_date.value == "2020-02-17"
-    assert invoice_object.invoice_date.confidence == 0.97
+    assert invoice_object.invoice_date.confidence == 0.99
     assert invoice_object.invoice_number.value == "0042004801351"
     assert invoice_object.invoice_number.confidence == 0.95
     assert (
@@ -60,8 +45,12 @@ Total amount including taxes: 587.95
 Total amount excluding taxes: 489.97
 Invoice date: 2020-02-17
 Invoice due date: 2020-02-17
-Supplier name: 1
-Payment details: 
+Supplier name: TURNPIKE DESIGNS CO.
+Supplier address: 156 University Ave, Toronto ON, Canada M5H 2H7
+Customer name: JIRO DOI
+Customer company registration: 
+Customer address: 1954 Bloon Street West Toronto, ON, M6P 3K9 Canada
+Payment details: FR7640254025476501124705368;
 Company numbers: 501124705; FR33501124705
 Taxes: 97.98 20.0%
 Total taxes: 97.98
@@ -299,25 +288,13 @@ def test__shouldnt_raise_when_tax_rate_none(invoice_pred):
     assert invoice.checklist["taxes_match_total_incl"] is False
 
 
-def test_empty_object_works():
-    invoice = Invoice()
-    assert invoice.total_tax.value is None
-
-
-def test_null_tax_rates_dont_raise():
-    invoice = Invoice(
-        locale="fr",
-        total_incl=12,
-        total_excl=15,
-        invoice_date="2018-12-21",
-        invoice_number="001",
-        due_date="2019-01-01",
-        taxes={(1, 0), (2, 20)},
-        supplier="Amazon",
-        payment_details="1231456498799765",
-        company_number="asdqsdae",
-        orientation=0,
-        total_tax=3,
-    )
+def test_null_tax_rates_dont_raise(invoice_pred):
+    invoice_pred["total_excl"] = {"value": 12, "confidence": 0.6}
+    invoice_pred["total_incl"] = {"value": 15, "confidence": 0.6}
+    invoice_pred["taxes"] = [
+        {"rate": 1, "value": 0.0, "confidence": 0.5},
+        {"rate": 2, "value": 20.0, "confidence": 0.5},
+    ]
+    invoice = Invoice(invoice_pred)
     assert invoice.checklist["taxes_match_total_incl"] is False
     assert invoice.checklist["taxes_match_total_excl"] is False
