@@ -4,7 +4,7 @@ from mindee.fields.orientation import Orientation
 def test_constructor():
     field_dict = {
         "degrees": 90,
-        "probability": 0.1,
+        "confidence": 0.1,
     }
     orientation = Orientation(field_dict)
     assert orientation.value == 90
@@ -13,7 +13,7 @@ def test_constructor():
 def test_not_number():
     field_dict = {
         "degrees": "aze",
-        "probability": 0.1,
+        "confidence": 0.1,
     }
     orientation = Orientation(field_dict)
     assert orientation.value == 0
@@ -22,7 +22,7 @@ def test_not_number():
 def test_not_90():
     field_dict = {
         "degrees": 255,
-        "probability": 0.1,
+        "confidence": 0.1,
     }
     orientation = Orientation(field_dict)
     assert orientation.value == 0
